{theme=documentation code-syntax=markdown}

\newcommand{Output}[
# Results in {.collapsible}
%{arg0}%
]


\newcommand{title title subtitle}[
# %{title}% {section-contentlist=False}

# %{subtitle}% {section-contentlist=False}
]


\component{brand}[![](https://avatars2.githubusercontent.com/u/47249302?s=25&v=4) *Lukeparser*]
\component{topright}[
- [\icon{fork}Github](http://www.github.com/lukeparser/lukeparser)
]
